// -------------- DirectX hooking example using the G4Mhook SDK -----------------
//
// This example combines the FiberThread hook method with the DirectX hooking 
// functionality. You'll need to install and set-up the directX SDK to compile
// this example. In order to reduce dependencies you should compile with the
// March 2008 DirectX SDK, as it is the version used by GTA IV. We also provide a
// better way to handle input, through the use of SetWindowsHookEx().
//
// --------------------- bean_xp - modmygta.com - 2009 --------------------------

#include <windows.h>
#include <d3d9.h>
#include <d3dx9.h>
#include "resource.h"

extern HMODULE hDLL;
extern bool godMode;

// Forward declaration of keyboard hook
LRESULT CALLBACK KeyboardProc(int nCode, WPARAM wParam, LPARAM lParam);

HHOOK keyboardHook;

// Called when GTA's Direct3D device is created, or after the device is reset
void DXHookInitialize(IDirect3DDevice9* m_device, D3DPRESENT_PARAMETERS* pPresentationParameters)
{
	// Add our keyboard hook
	if (!keyboardHook) keyboardHook = SetWindowsHookEx(WH_KEYBOARD, &KeyboardProc, hDLL, GetCurrentThreadId());
}

ID3DXSprite * Sprite = NULL;
IDirect3DTexture9 * InvulnGlyph = NULL;

// Called when GTA has finished rendering, before EndScene is called
void DXHookRender(IDirect3DDevice9* m_device)
{
	// If we don't have a sprite, make one, if we can't make one, don't go any further
	if (!Sprite)
		if (FAILED(D3DXCreateSprite(m_device, &Sprite)))
			return;

	// If the texture isn't loaded, load it, if we can't, don't go any further
	if (!InvulnGlyph)
		if(FAILED(D3DXCreateTextureFromResourceEx(m_device,
												  hDLL,
												  MAKEINTRESOURCE(IDR_GLYPH),
												  32,
												  32,
												  D3DX_DEFAULT,
												  0,
												  D3DFMT_A8B8G8R8,
												  D3DPOOL_MANAGED,
												  D3DX_DEFAULT,
												  D3DX_DEFAULT,
												  0,
												  NULL,
												  NULL,
												  &InvulnGlyph)))
			return;

	// Draw the glyph
	if (godMode)
	{
		D3DXVECTOR3 Position = D3DXVECTOR3(10, 10, 0);

		Sprite->Begin(D3DXSPRITE_ALPHABLEND);
		Sprite->Draw(InvulnGlyph, NULL, NULL, &Position, D3DCOLOR_ARGB(255, 255, 255, 255)); 
		Sprite->End();
	}
}

// Called when the device is reset
void DXHookReset()
{
	if (Sprite) { Sprite->Release(); Sprite = 0; }
	if (InvulnGlyph) { InvulnGlyph->Release(); InvulnGlyph = 0; }
}

LRESULT CALLBACK KeyboardProc(int nCode, WPARAM wParam, LPARAM lParam)
{
	// Filter out repeat keypresses
	if ((nCode == HC_ACTION) && !(lParam &0x40000000)) 
	{
		// Toggle godmode on F1 keypresses
		if (wParam == VK_F1) godMode ^= true;
	}	

	return CallNextHookEx(keyboardHook, nCode, wParam, lParam);
}